hexmarkers.overdisp: Simulated overdispersed autopolyploid dominant markers from...

hexmarkers.overdispR Documentation

Simulated overdispersed autopolyploid dominant markers from 200 hexaploid individuals

Description

These data are simulated as 500 markers for 200 “auto–hexaploid individuals” exhibiting overdispersion with the parameter shape1 = 25. The underlying percentages of single double and triple dose markers are 70%, 20% and 10%, respectively.

Usage

hexmarkers.overdisp

Format

An object of S3 class sim.autoMarkers containing 500 simulated dominant markers for 200 auto–hexaploid individuals.

References

Haldane, J B S. 1930. Theoretical genetics of autopolyploids. Journal of Genetics 22: 359-372.

Baker P, Jackson P, and Aitken K. 2010. Bayesian estimation of marker dosage in sugarcane and other autopolyploids. TAG Theoretical and Applied Genetics 120 (8): 1653-1672.


polySegratioMM documentation built on Feb. 25, 2026, 5:08 p.m.