| plot.segratioMCMC | R Documentation |
Standard MCMC trace and density plots for specified mixure model parameters and posterior probability distributions for specified markers
## S3 method for class 'segratioMCMC'
plot(x, ..., row.index = c(1:10), var.index = c(1:6),
marker.index = c(1:8))
x |
object of class |
... |
extra options for printing |
row.index |
which rows to print (Default: first 10) |
var.index |
which mixture model variable to summarise (Default: all) |
marker.index |
which markers to summarise (Default: 1:8) |
None.
Peter Baker drpetebaker@gmail.com
dosagesMCMC readJags
## simulate small autooctaploid data set
a1 <- sim.autoMarkers(8,c(0.7,0.2,0.1),n.markers=100,n.individuals=50)
##print(a1)
sr <- segregationRatios(a1$markers)
x <- setModel(3,8)
## Not run:
## fit simple model in one hit and summarise
x.run <- runSegratioMM(sr, x, burn.in=200, sample=500)
plot(x.run$mcmc.mixture)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.