| setModel | R Documentation |
Used to automatically set up Bayesian finite mixture models for dosage allocation of dominant markers in autopolyploids given the number of components and ploidy level
setModel(n.components, ploidy.level, random.effect = FALSE, seg.ratios =NULL,
ploidy.name = NULL, equal.variances=TRUE,
type.parents = c("heterogeneous", "homozygous"))
n.components |
number of components for mixture model (less than or equal to maximum number of possible dosages) |
ploidy.level |
the number of homologous chromosomes, either as numeric or as a character string |
random.effect |
Logical indicating whether model contains random
effect (Default: |
seg.ratios |
segregation proportions for each marker provided as
S3 class |
ploidy.name |
Can overide ploidy name here or allow it to be
determined from |
equal.variances |
Logical indicating whether model contains
separate or common variances for each component (Default: |
type.parents |
"heterogeneous" if parental markers are 0,1 or "homogeneous" if parental markers are both 1 |
Returns object of class modelSegratioMM with components
bugs.code |
text to be used by |
n.components |
number of components for mixture model |
monitor.var |
names of variables to be monitored in |
ploidy.level |
ploidy level |
random.effect |
Logical indicating whether model contains random
effect (Default: |
equal.variances |
Logical indicating equal or separate variances for each component |
E.segRatio |
Expected segregation ratios |
type.parents |
"heterogeneous" if parental markers are 0,1 or "homogeneous" if parental markers are both 1 |
call |
function call |
Peter Baker drpetebaker@gmail.com
setPriors setInits
expected.segRatio
segRatio
setControl
dumpData dumpInits or for an easier way to
run a segregation ratio mixture model see
runSegratioMM
## simulate small autooctaploid data set
a1 <- sim.autoMarkers(8,c(0.7,0.2,0.1),n.markers=100,n.individuals=50)
## set up model with 3 components
x <- setModel(3,8)
print(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.