Learn R Programming

polySegratioMM (version 0.6-5)

plot.segratioMCMC: MCMC plots for segregation ratio mixture models

Description

Standard MCMC trace and density plots for specified mixure model parameters and posterior probability distributions for specified markers

Usage

# S3 method for segratioMCMC
plot(x, ..., row.index = c(1:10), var.index = c(1:6),
marker.index = c(1:8))

Value

None.

Arguments

x

object of class segratioMCMC

...

extra options for printing

row.index

which rows to print (Default: first 10)

var.index

which mixture model variable to summarise (Default: all)

marker.index

which markers to summarise (Default: 1:8)

Author

Peter Baker drpetebaker@gmail.com

See Also

dosagesMCMC readJags

Examples

Run this code
## simulate small autooctaploid data set
a1 <- sim.autoMarkers(8,c(0.7,0.2,0.1),n.markers=100,n.individuals=50)
##print(a1)
sr <-  segregationRatios(a1$markers)
x <- setModel(3,8)

if (FALSE) {
## fit simple model in one hit and summarise

x.run <- runSegratioMM(sr, x, burn.in=200, sample=500)
plot(x.run$mcmc.mixture)
}

Run the code above in your browser using DataLab